@@ -9,6 +9,14 @@ mod crossdev;
 mod interactive;
 mod options;
 
+fn stderr_if_tty() -> Option<io::Stderr> {
+    if atty::is(atty::Stream::Stderr) {
+        Some(io::stderr())
+    } else {
+        None
+    }
+}
+
 fn main() -> Result<()> {
     use options::Command::*;
 
@@ -67,6 +75,7 @@ fn main() -> Result<()> {
             let stdout_locked = stdout.lock();
             let (res, stats) = dua::aggregate(
                 stdout_locked,
+                stderr_if_tty(),
                 walk_options,
                 !no_total,
                 !no_sort,
@@ -82,6 +91,7 @@ fn main() -> Result<()> {
             let stdout_locked = stdout.lock();
             dua::aggregate(
                 stdout_locked,
+                stderr_if_tty(),
                 walk_options,
                 true,
                 true,
